#ifndef QTHELLOSETTINGS_H
#define QTHELLOSETTINGS_H

class QthelloSettings
{
public:
    QthelloSettings();
    ~QthelloSettings();

    int animationSpeed() const { return animationSpeed_; }
    bool saveMode() const { return saveMode_; }
    bool startNewGame() const { return startNewGame_; }
    int mode() const { return mode_; }
    int AILevel() const { return AILevel_; }
    void setAnimationSpeed(int animSpeed) { animationSpeed_ = animSpeed; }
    void setSaveMode(bool sm) { saveMode_ = sm; }
    void setMode(int m) { mode_ = m; }
    void setAILevel(int level) { AILevel_ = level;}
    void setStartNewGame(bool s) { startNewGame_ = s; }
private:
    int animationSpeed_;
    bool saveMode_;
    int mode_;
    int AILevel_;
    bool startNewGame_;
};

#endif // QTHELLOSETTINGS_H
